@@ -5,13 +5,23 @@ use pad::{Alignment, PadStr};
 #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 pub trait AutoDeriveFromEnvironment: FromEnvironment {}
 
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 impl<P: AutoDeriveFromEnvironment> AutoDeriveFromEnvironment for Option<P> {}
 
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
+/// Context for implementing description.
+#[allow(missing_debug_implementations)]
+pub struct SalakDescContext<'a> {
+    pub(crate) key: &'a mut Key<'a>,
+    pub(crate) descs: &'a mut Vec<KeyDesc>,
+    pub(crate) current: KeyDesc,
+}
+
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 /// Generate description for this object.
 pub trait DescFromEnvironment: FromEnvironment {
     /// Generate key description from [`SalakDescContext`].
     /// * `env` - Describable context.
-    #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
     fn key_desc(env: &mut SalakDescContext<'_>);
 }
 
@@ -23,7 +33,9 @@ pub trait PrefixedFromEnvironment: DescFromEnvironment {
     fn prefix() -> &'static str;
 }
 
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 impl<P: PrefixedFromEnvironment> PrefixedFromEnvironment for Option<P> {
+    #[inline]
     fn prefix() -> &'static str {
         P::prefix()
     }
